@@ -1,35 +1,39 @@
 from gdata.youtube.service import YouTubeService, YOUTUBE_PLAYLIST_FEED_URI
 from massmedia import settings
+from django.http import QueryDict
+from urlparse import urlparse
+
 
 class YouTubeBase(object):
     """
     A simple class to get the info for a youtube feed
     """
-    
+
     def __init__(self, url=None):
         self.url = url
         self._service = None
         self.metadata = {}
         self.entries = []
         self.process_url()
-    
+
     def process_url(self):
         """
         Overridden by subclasses
         """
         pass
-    
+
     def get_service(self):
         """
         Return the cached service object or get it and cache it.
         """
         if self._service is None:
             self._service = YouTubeService()
-            self._service.email = settings.SERVICES['YOUTUBE']['EMAIL']
-            self._service.password = settings.SERVICES['YOUTUBE']['PASSWORD']
-            self._service.ProgrammaticLogin()
+            if settings.SERVICES['YOUTUBE']['EMAIL'] != '' and settings.SERVICES['YOUTUBE']['PASSWORD'] != '':
+                self._service.email = settings.SERVICES['YOUTUBE']['EMAIL']
+                self._service.password = settings.SERVICES['YOUTUBE']['PASSWORD']
+                self._service.ProgrammaticLogin()
         return self._service
-    
+
     @staticmethod
     def get_url_from_links(link_list, rel):
         """
@@ -38,7 +42,7 @@ class YouTubeBase(object):
         for item in link_list:
             if item.rel == rel:
                 return item.href
-    
+
     @staticmethod
     def get_default_content(content_list):
         """
@@ -47,7 +51,7 @@ class YouTubeBase(object):
         for fmt in content_list:
             if 'isDefault' in fmt.extension_attributes:
                 return fmt
-    
+
     @staticmethod
     def get_biggest_thumbnail(thumb_list):
         """
@@ -65,7 +69,7 @@ class YouTubeBase(object):
                     biggest = item
                     big_size = item_size
         return biggest
-    
+
     @staticmethod
     def convert_to_python(element):
         """
@@ -73,7 +77,7 @@ class YouTubeBase(object):
         """
         from atom.core import XmlElement
         from atom import AtomBase
-        
+
         ignorable_keys = ['scheme', 'namespace']
         if isinstance(element, (list, tuple)):
             output = []
@@ -130,17 +134,9 @@ class YouTubeFeed(YouTubeBase):
         Process the feed url and set the metadata and entries
         """
         if 'gdata.youtube.com' not in self.url:
-            import re
-            playlistid_re = re.compile("(?:user/|p=|#p/c/)([A-F0-9]{16})$")
-            search = playlistid_re.search(self.url)
-            if search:
-                playlist_id = search.group(1)
-            else:
-                return
+            playlist_id = QueryDict(urlparse(self.url).query)['list']
             self.url = "%s/%s" % (YOUTUBE_PLAYLIST_FEED_URI, playlist_id)
         feed = self.get_service().GetYouTubeVideoFeed(uri=self.url)
         self.metadata = self.convert_to_python(feed.__dict__)
         self.entries = self.metadata['entry'][:]
         del self.metadata['entry']
-
-
